@@ -18,7 +18,7 @@ use Carp qw( croak );
 use Smart::Comments;
 
 use base qw( Net::SSH::Perl );
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Errno qw( EAGAIN EWOULDBLOCK );
 use vars qw( $VERSION $CONFIG $HOSTNAME @PROPOSAL );
@@ -1072,9 +1072,9 @@ AnyEvent::SSH2 - 基于 AnyEvent 的 SSH2 的事件驱动的实现
 
     use AnyEvent::SSH2;
     my $ssh = AnyEvent::SSH2->new(
-        '117.79.131.136',
+        'ip'
         user => 'root',
-        pass => 'YYTBIG$100%',
+        pass => 'pass',
     );   
     
     
